import {
  select,
  csv,
  pie,
  arc,
  scaleOrdinal,
  schemeCategory10,
} from 'd3';

const svg = select("svg");
const width = +svg.attr('width');
const height = +svg.attr('height');

// dollors 
const numberFormat = number =>
  	(Math.abs(Number(number))) + " %" ;


const render = data => {
  const pieData = pie().sort(null).value(d=>d.Crime_Index)(data);
  const colors = scaleOrdinal(schemeCategory10);
	const segments = arc()
  	.innerRadius(0)
  	.outerRadius(200)
  	.padAngle(0)
  	.padRadius(0);
  
  const sections = svg.append("g")
  	.attr("transform", `translate(250,250)`)
  	.selectAll("path").data(pieData);
  sections.enter().append("path").attr("d", segments)
  	.attr("fill", d => colors(d.data.Crime_Index))
  	.on("mouseover", d => console.log(d.data.Crime_Index));
  //piechart is created 
  const legends = svg.append("g")
  	.attr("transform", "translate(500,100)")
    .selectAll(".legends").data(pieData);
  const legend = legends.enter().append("g").classed(".legends",true)
  	.attr("transform", (d,i)=>{
      return `translate(0,${(i+1)*30})`;
    });
  
  // list of each country as labels and its styles

  legend.append("rect").attr("width",22).attr("height",25)
  	.attr("fill", d => colors(d.data.Crime_Index));
  legend.append("text")
  	.attr("x", 28)
  	.attr("y", 18)
  	.attr("class","legend_text")
  	.text(d => d.data.Country);
  legend.append("text")
  	.attr("x", 260)
  	.attr("y", 20)
  	.attr("class","legend_value")
  	.text(d=>numberFormat(d.data.Crime_Index));
}

// url of my data giest

const csvUrl =
 'https://gist.githubusercontent.com/bhanuprasadk19/b9a350be33815c25f47af3aaf4515888/raw/275e5c37e30ea955808ebbfb8ff7033d0d80553f/Crime1.csv';


//Load the data for Crime Index By countries 2020
csv(csvUrl).then(csvData => {
    csvData.sort((data1, data2) => data2.Crime_Index-data1.Crime_Index);
    if (csvData) {
      render(csvData.slice(0, 10));
    }
});